@@ -2,7 +2,6 @@
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "messagedelegate.h"
-#include "timelinedelegate.h"
 
 #include <algorithm>
 #include <cmath>
@@ -53,6 +52,9 @@ MessageDelegateBase::~MessageDelegateBase()
 {
     for (const auto &incubator : m_activeIncubators) {
         incubator->clear();
+        if (const auto object = qobject_cast<QQuickItem *>(incubator->object())) {
+            cleanupItem(object);
+        }
         delete incubator;
     }
 }
@@ -87,6 +89,7 @@ void MessageDelegateBase::setIsThreaded(bool isThreaded)
     m_isThreaded = isThreaded;
     setAlwaysFillWidth(m_isThreaded || m_compactMode);
     setPercentageValues(m_isThreaded || m_compactMode);
+    updateAvatar();
     Q_EMIT isThreadedChanged();
 }
 
@@ -146,6 +149,10 @@ qreal MessageDelegateBase::maxContentWidth() const
 
 void MessageDelegateBase::cleanupIncubator(MessageObjectIncubator *incubator)
 {
+    if (!incubator) {
+        return;
+    }
+
     incubator->clear();
     const auto it = std::find(m_activeIncubators.begin(), m_activeIncubators.end(), incubator);
     if (it != m_activeIncubators.end()) {
@@ -418,6 +425,7 @@ void MessageDelegateBase::setCompactMode(bool compactMode)
 
     updateBackground();
     updateQuickAction();
+    updateAvatar();
 }
 
 void MessageDelegateBase::updateBackground()
@@ -470,35 +478,40 @@ void MessageDelegateBase::setQuickActionComponent(QQmlComponent *quickActionComp
 
 void MessageDelegateBase::updateQuickAction()
 {
-    if (m_quickActionComponent && !m_compactMode && m_hovered && !m_quickActionItem && !m_quickActionIncubating) {
-        const auto quickActionIncubator = new MessageObjectIncubator(
-            m_objectInitialCallback,
-            [this](MessageObjectIncubator *incubator) {
-                if (!incubator) {
-                    return;
-                }
-
-                const auto quickActionObject = qobject_cast<QQuickItem *>(incubator->object());
-                if (quickActionObject) {
-                    if (!m_compactMode) {
-                        m_quickActionItem = quickActionObject;
-                        connect(m_quickActionItem, SIGNAL(reactingChanged()), this, SLOT(updateQuickAction()));
-                    } else {
-                        cleanupItem(quickActionObject);
-                    }
-                    markAsDirty();
-                }
-                m_quickActionIncubating = false;
-                cleanupIncubator(incubator);
-            },
-            m_errorCallback);
-        m_activeIncubators.push_back(quickActionIncubator);
-        m_quickActionComponent->create(*quickActionIncubator, qmlContext(m_quickActionComponent));
-        m_quickActionIncubating = true;
-    } else if (m_quickActionItem && !m_hovered && !m_quickActionItem->property("reacting").toBool()) {
-        cleanupItem(m_quickActionItem);
-        markAsDirty();
+    if (!m_hovered || m_compactMode) {
+        if (m_quickActionItem && (!m_quickActionItem->property("reacting").toBool() || m_compactMode)) {
+            cleanupItem(m_quickActionItem);
+            markAsDirty();
+        }
+        return;
     }
+    if (!m_quickActionComponent || m_quickActionItem || m_quickActionIncubating) {
+        return;
+    }
+
+    m_quickActionIncubating = true;
+    const auto quickActionIncubator = new MessageObjectIncubator(
+        m_objectInitialCallback,
+        [this](MessageObjectIncubator *incubator) {
+            if (!incubator) {
+                return;
+            }
+
+            if (const auto quickActionObject = qobject_cast<QQuickItem *>(incubator->object())) {
+                if (!m_compactMode) {
+                    m_quickActionItem = quickActionObject;
+                    connect(m_quickActionItem, SIGNAL(reactingChanged()), this, SLOT(updateQuickAction()));
+                } else {
+                    cleanupItem(quickActionObject);
+                }
+                markAsDirty();
+            }
+            cleanupIncubator(incubator);
+            m_quickActionIncubating = false;
+        },
+        m_errorCallback);
+    m_activeIncubators.push_back(quickActionIncubator);
+    m_quickActionComponent->create(*quickActionIncubator, qmlContext(m_quickActionComponent));
 }
 
 bool MessageDelegateBase::showLocalMessagesOnRight() const
@@ -632,7 +645,7 @@ void MessageDelegateBase::hoverEnterEvent(QHoverEvent *event)
 void MessageDelegateBase::hoverMoveEvent(QHoverEvent *event)
 {
     bool oldHovered = m_hovered;
-    m_hovered = contains(event->pos());
+    m_hovered = contains(event->position());
     if (oldHovered != m_hovered) {
         Q_EMIT hoveredChanged();
     }
